@@ -21,6 +21,7 @@ from collections import namedtuple
 from tornado import gen
 from nbformat.v4 import new_notebook
 from .cortx_authenticator import CortxAuthenticator
+from .utils import MultiPartUploadHelper
 import json 
 
 import nbformat
@@ -31,58 +32,12 @@ Config = namedtuple('Config', [
  'prefix', 'region', 'bucket_name', 'host_name', 'cortx_authenticator',
     'multipart_uploads', 'endpoint_url'
 ])
-# CredentialConfig = namedtuple('CredentialConfig', [
-#     'access_key_id', 'secret_access_key'
-# ])
-
-
-class ExpiringDict:
-
-    def __init__(self, seconds):
-        self._seconds = seconds
-        self._store = {}
-
-    def _remove_old_keys(self, now):
-        self._store = {
-            key: (expires, value)
-            for key, (expires, value) in self._store.items()
-            if expires > now
-        }
-
-    def __getitem__(self, key):
-        now = int(time.time())
-        self._remove_old_keys(now)
-        return self._store[key][1]
-
-    def __setitem__(self, key, value):
-        now = int(time.time())
-        self._remove_old_keys(now)
-        self._store[key] = (now + self._seconds, value)
-
-    def __delitem__(self, key):
-        now = int(time.time())
-        self._remove_old_keys(now)
-        del self._store[key]
 
 
 # class Datetime(TraitType):
 #     klass = datetime.datetime
 #     default_value = datetime.datetime(1900, 1, 1)
 
-
-# class CortxAuthenticator(Configurable):
-#     access_key_id = Unicode(config=True)
-#     secret_access_key = Unicode(config=True)
-
-#     @gen.coroutine
-#     def get_credentials(self):
-#         return CredentialConfig(
-#             access_key_id=self.access_key_id,
-#             secret_access_key=self.secret_access_key,
-#         )
-
-
-
 class CortxJupyter(ContentsManager):
 
     bucket_name = Unicode(config=True)
@@ -105,11 +60,11 @@ class CortxJupyter(ContentsManager):
     def _write_lock_default(self):
         return Lock()
 
-    multipart_uploads = Instance(ExpiringDict)
+    multipart_uploads = Instance(MultiPartUploadHelper)
 
     @default('multipart_uploads')
     def _multipart_uploads_default(self):
-        return ExpiringDict(60 * 60 * 1)
+        return MultiPartUploadHelper(60 * 60 * 1)
 
     def is_hidden(self, path):
         return False
